summaryrefslogtreecommitdiff
path: root/gst/gsttypefind.h
diff options
context:
space:
mode:
authorWim Taymans <wim.taymans@collabora.co.uk>2011-08-26 14:37:54 +0200
committerWim Taymans <wim.taymans@collabora.co.uk>2011-08-26 14:37:54 +0200
commit5cf8e689440493c51cfc94e178af94f25b04e526 (patch)
treefcffdf4cf6ef72bff97316f527e5c72d8182d580 /gst/gsttypefind.h
parentd924c30f5b881677c32e10b63c844c20d41d526a (diff)
parent185ab7f325da9b8ff3f9c9e16b47d2bea2fc3636 (diff)
downloadgstreamer-5cf8e689440493c51cfc94e178af94f25b04e526.tar.gz
Merge branch 'master' into 0.11
Conflicts: gst/gstmessage.c gst/gstquery.c gst/gstregistrychunks.c gst/gstsegment.c libs/gst/base/gstbasetransform.c libs/gst/base/gstbasetransform.h libs/gst/base/gsttypefindhelper.c plugins/elements/gsttypefindelement.c
Diffstat (limited to 'gst/gsttypefind.h')
-rw-r--r--gst/gsttypefind.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/gst/gsttypefind.h b/gst/gsttypefind.h
index 036148c7a1..27c7e32d0a 100644
--- a/gst/gsttypefind.h
+++ b/gst/gsttypefind.h
@@ -44,16 +44,18 @@ typedef void (* GstTypeFindFunction) (GstTypeFind *find, gpointer data);
/**
* GstTypeFindProbability:
* @GST_TYPE_FIND_MINIMUM: unlikely typefind
* @GST_TYPE_FIND_POSSIBLE: possible type detected
* @GST_TYPE_FIND_LIKELY: likely a type was detected
* @GST_TYPE_FIND_NEARLY_CERTAIN: nearly certain that a type was detected
* @GST_TYPE_FIND_MAXIMUM: very certain a type was detected.
*
* The probability of the typefind function. Higher values have more certainty
* in doing a reliable typefind.
*/
typedef enum {
+ GST_TYPE_FIND_NONE = 0,
GST_TYPE_FIND_MINIMUM = 1,
GST_TYPE_FIND_POSSIBLE = 50,
GST_TYPE_FIND_LIKELY = 80,
@@ -44,16 +44,18 @@ typedef void (* GstTypeFindFunction) (GstTypeFind *find, gpointer data);
/**
* GstTypeFindProbability:
- * @GST_TYPE_FIND_MINIMUM: unlikely typefind
- * @GST_TYPE_FIND_POSSIBLE: possible type detected
- * @GST_TYPE_FIND_LIKELY: likely a type was detected
- * @GST_TYPE_FIND_NEARLY_CERTAIN: nearly certain that a type was detected
+ * @GST_TYPE_FIND_NONE: type undetected. Since 0.10.36.
+ * @GST_TYPE_FIND_MINIMUM: unlikely typefind.
+ * @GST_TYPE_FIND_POSSIBLE: possible type detected.
+ * @GST_TYPE_FIND_LIKELY: likely a type was detected.
+ * @GST_TYPE_FIND_NEARLY_CERTAIN: nearly certain that a type was detected.
* @GST_TYPE_FIND_MAXIMUM: very certain a type was detected.
*